@@ -13,6 +13,73 @@ import dill
 import plotly.express as px
 
 
+def find_strike_call(S, T, r, sigma, d):
+    return S * np.e ** (
+        (-1 * (norm.ppf(d) * sigma * np.sqrt(T)) + 0.5 * np.power(sigma, 2) * T)
+    )
+
+
+def find_strike_put(S, T, r, sigma, d):
+    return S * np.e ** (
+        (1 * (norm.ppf(d) * sigma * np.sqrt(T)) + 0.5 * np.power(sigma, 2) * T)
+    )
+
+
+def d1(S, K, T, r, sigma):
+    return (np.log(S / K) + (r + sigma**2 / 2.0) * T) / (sigma * sqrt(T))
+
+
+def d2(S, K, T, r, sigma):
+    return d1(S, K, T, r, sigma) - sigma * sqrt(T)
+
+
+def bs_call(S, K, T, r, sigma):
+    return S * norm.cdf(d1(S, K, T, r, sigma)) - K * np.exp(-r * T) * norm.cdf(
+        d2(S, K, T, r, sigma)
+    )
+
+
+def bs_put(S, K, T, r, sigma):
+    return K * np.exp(-r * T) * norm.cdf(-d2(S, K, T, r, sigma)) - S * norm.cdf(
+        -d1(S, K, T, r, sigma)
+    )
+
+
+def call_delta(S, K, T, r, sigma):
+    return np.exp(-r * T) * norm.cdf(d1(S, K, T, r, sigma))
+
+
+def put_delta(S, K, T, r, sigma):
+    return -1 * (np.exp(-r * T) * norm.cdf(d1(S, K, T, r, sigma)) - 1)
+
+
+def find_delta(optiontype: str, K, T, r, sigma):
+    if optiontype == "C":
+        return call_delta(S, K, T, r, sigma)
+    elif optiontype == "P":
+        return put_delta(S, K, T, r, sigma)
+    else:
+        raise ValueError("Option type must be either C or P")
+
+
+def find_premium(optiontype: str, K, T, r, sigma):
+    if optiontype == "C":
+        return bs_call(S, K, T, r, sigma)
+    elif optiontype == "P":
+        return bs_put(S, K, T, r, sigma)
+    else:
+        raise ValueError("Option type must be either C or P")
+
+
+def find_strike(optiontype: str, S, T, r, sigma, d):
+    if optiontype == "C":
+        return find_strike_call(S, T, r, sigma, d)
+    elif optiontype == "P":
+        return find_strike_put(S, T, r, sigma, d)
+    else:
+        raise ValueError("Option type must be either C or P")
+
+
 class Surface:
     def __init__(self, df, datestr, putcall, symbol, spot):
         # Need to sort the tail ends by putCall
